@@ -1,3 +1,4 @@
+
 #ifndef GO_CMD_CONTEXT_IMPL_H
 #define GO_CMD_CONTEXT_IMPL_H
 
@@ -12,9 +13,10 @@ typedef struct {
 					 char const *filename);
 	void    (*set_sensitive)	(GOCmdContext *gcc,
 					 gboolean sensitive);
-	struct {
+	struct _GOCmdContextIface {
 		void (*error)		(GOCmdContext *gcc, GError *err);
 		void (*error_info)  	(GOCmdContext *gcc, GOErrorInfo *err);
+		void (*error_info_list) (GOCmdContext *gcc, GSList *errs);
 	} error;
 
 	void    (*progress_set)		(GOCmdContext *gcc, double val);
@@ -24,10 +26,6 @@ typedef struct {
 #define GO_CMD_CONTEXT_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), GO_TYPE_CMD_CONTEXT, GOCmdContextClass))
 #define GO_IS_CMD_CONTEXT_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE((k), GO_TYPE_CMD_CONTEXT))
 
-/* protected, these do not really belong here, they are associated with io-context */
-void  go_cmd_context_progress_set	  (GOCmdContext *gcc, double f);
-void  go_cmd_context_progress_message_set (GOCmdContext *gcc, char const *msg);
-
 G_END_DECLS
 
 #endif /* GO_CMD_CONTEXT_IMPL_H */
