@@ -1,10 +1,10 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-rotation-sel.h - Select a text orientation
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,6 +31,7 @@ typedef struct _GORotationSel GORotationSel;
 
 GType      go_rotation_sel_get_type (void);
 GtkWidget *go_rotation_sel_new      (void);
+GtkWidget *go_rotation_sel_new_full (void);
 void	   go_rotation_sel_set_rotation (GORotationSel *rs, int degrees);
 int	   go_rotation_sel_get_rotation (GORotationSel const *rs);
 
